summaryrefslogtreecommitdiff
path: root/src/cairo-array.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/cairo-array.c')
-rw-r--r--src/cairo-array.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/cairo-array.c b/src/cairo-array.c
index a37ea9af5..a9f148a07 100644
--- a/src/cairo-array.c
+++ b/src/cairo-array.c
@@ -147,7 +147,7 @@ typedef struct {
*
* Initializes a #cairo_user_data_array_t structure for future
* use. After initialization, the array has no keys. Call
* _cairo_user_data_array_destroy() to free any allocated memory
* when done using the array.
**/
void
@@ -157,14 +157,14 @@ _cairo_user_data_array_init (cairo_user_data_array_t *array)
}
/**
- * _cairo_user_data_array_destroy:
+ * _cairo_user_data_array_fini:
* @array: a #cairo_user_data_array_t
*
* Destroys all current keys in the user data array and deallocates
* any memory allocated for the array itself.
**/
void
-_cairo_user_data_array_destroy (cairo_user_data_array_t *array)
+_cairo_user_data_array_fini (cairo_user_data_array_t *array)
{
int i, num_slots;
cairo_user_data_slot_t *slots;
@@ -147,7 +147,7 @@ typedef struct {
* Initializes a #cairo_user_data_array_t structure for future
* use. After initialization, the array has no keys. Call
- * _cairo_user_data_array_destroy() to free any allocated memory
+ * _cairo_user_data_array_fini() to free any allocated memory
* when done using the array.
**/